@@ -227,8 +227,25 @@ def main():
             project_id = get_proj_id(apikey, baseurl, scan_id)
 
         percentage = 0
+        retry = 10
+
+        logger.info(f"scan id: {scan_id}")
         while status != "finished" and status != "failed":
-            status, scan_percentage = check_scan(scan_id, project_id, apikey, baseurl)
+            scan_status, scan_percentage = check_scan(scan_id, project_id, apikey, baseurl)
+
+            if scan_percentage is None and scan_status not in ["finished", "failed", "queued", "running", "processed"]:
+                # fail to find scan
+                retry += 1
+                logger.info(scan_status + f"({retry}/10)")
+
+                if retry > 10:
+                    logger.error("Fail to get scan infomation, please manually check scan status on website.")
+                    exit(1)
+                else:
+                    time.sleep(10)
+                    continue
+
+            status = scan_status
             if scan_percentage and scan_percentage != percentage:
                 percentage = scan_percentage
                 logger.info("scan percentage: " + str(percentage) + "%")
