@@ -19,7 +19,7 @@ def check_scan(scan_id, project_id, apikey, baseurl):
     }
     result = requests.get(url=url, headers=headers)
     if result.status_code not in [200, 201]:
-        return {"error": "failed to get scan"}
+        return f"failed to get scan, return code {result.status_code}, message: {result.text}. Will retry in 10 seconds.", None
     return result.json().get("status"), result.json().get("scan_percentage")
     # async with session.get(url=url, headers=headers) as r:
     #     if r.status not in [200, 201]:
