@@ -49,13 +49,13 @@ def get_scan_id(apikey, baseurl, project_id):
             f"can not get the project (id: {project_id}) info, please try again or check your project id"
         )
 
-    if "lastScan" not in result.json():
+    if "last_scan" not in result.json():
         error_exit(
             f"the latest scan not found in project {project_id}. Please try again or check your project id."
         )
 
     logger.debug(result.json())
-    return result.json()["lastScan"]["id"]
+    return result.json()["last_scan"]["id"]
 
 
 def create_scan(project_id, scan_type, branch, apikey, baseurl):
@@ -77,7 +77,7 @@ def create_scan(project_id, scan_type, branch, apikey, baseurl):
     r = requests.post(url=url, headers=headers, json=payload)
     if r.status_code not in [200, 201]:
         error_exit("failed to create scan")
-    scan_id = r.json().get("project").get("lastScan").get("id")
+    scan_id = r.json().get("project").get("last_scan").get("id")
     return {"scan_id": scan_id}
 
 
