@@ -1,6 +1,7 @@
 from urllib import parse as parseurl
+
 import requests
-from command_tool.utils.utils import logger, error_exit
+from command_tool.utils.utils import error_exit, logger
 
 
 def show_teams(apikey, baseurl):
