@@ -1,11 +1,12 @@
-import requests
 from urllib import parse as parseurl
-from command_tool.utils.utils import logger, error_exit
+
+import requests
+from command_tool.utils.utils import error_exit, logger
 
 
 def show_user(apikey, baseurl):
     """
-        get user information through API and return needed information
+    get user information through API and return needed information
     """
     endpoint = "/v1/user/"
     headers = {
