@@ -88,4 +88,8 @@ def get_upload_zip_file(path):
     else:
         error_exit("Please provide a valid file path")
 
-    return file
\ No newline at end of file
+    return file
+
+
+def debug_logger_level():
+    logging.basicConfig(level=logging.DEBUG, format=FORMAT)
